@@ -7,7 +7,7 @@
 #  define VTKPVCATALYST_NO_EXPORT
 #else
 #  ifndef VTKPVCATALYST_EXPORT
-#    ifdef vtkPVCatalyst_EXPORTS
+#    ifdef Catalyst_EXPORTS
         /* We are building this library */
 #      define VTKPVCATALYST_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,20 @@
 
 #ifndef VTKPVCATALYST_DEPRECATED
 #  define VTKPVCATALYST_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVCATALYST_DEPRECATED_EXPORT VTKPVCATALYST_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVCATALYST_DEPRECATED_NO_EXPORT VTKPVCATALYST_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVCATALYST_NO_DEPRECATED
+#ifndef VTKPVCATALYST_DEPRECATED_EXPORT
+#  define VTKPVCATALYST_DEPRECATED_EXPORT VTKPVCATALYST_EXPORT VTKPVCATALYST_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkPVServerManagerApplicationModule.h"
-
+#ifndef VTKPVCATALYST_DEPRECATED_NO_EXPORT
+#  define VTKPVCATALYST_DEPRECATED_NO_EXPORT VTKPVCATALYST_NO_EXPORT VTKPVCATALYST_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVCATALYST_NO_DEPRECATED
+#    define VTKPVCATALYST_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVCATALYST_EXPORT_H */
