@@ -7,7 +7,7 @@
 #  define VTKPVCINEMAREADER_NO_EXPORT
 #else
 #  ifndef VTKPVCINEMAREADER_EXPORT
-#    ifdef vtkPVCinemaReader_EXPORTS
+#    ifdef CinemaReader_EXPORTS
         /* We are building this library */
 #      define VTKPVCINEMAREADER_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,17 +23,20 @@
 
 #ifndef VTKPVCINEMAREADER_DEPRECATED
 #  define VTKPVCINEMAREADER_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVCINEMAREADER_DEPRECATED_EXPORT VTKPVCINEMAREADER_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVCINEMAREADER_DEPRECATED_NO_EXPORT VTKPVCINEMAREADER_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVCINEMAREADER_NO_DEPRECATED
+#ifndef VTKPVCINEMAREADER_DEPRECATED_EXPORT
+#  define VTKPVCINEMAREADER_DEPRECATED_EXPORT VTKPVCINEMAREADER_EXPORT VTKPVCINEMAREADER_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkPVServerManagerCoreModule.h"
-#include "vtkRenderingCoreModule.h"
-
+#ifndef VTKPVCINEMAREADER_DEPRECATED_NO_EXPORT
+#  define VTKPVCINEMAREADER_DEPRECATED_NO_EXPORT VTKPVCINEMAREADER_NO_EXPORT VTKPVCINEMAREADER_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVCINEMAREADER_NO_DEPRECATED
+#    define VTKPVCINEMAREADER_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVCINEMAREADER_EXPORT_H */
