@@ -7,7 +7,7 @@
 #  define VTKPVCLIENTSERVERCORECORE_NO_EXPORT
 #else
 #  ifndef VTKPVCLIENTSERVERCORECORE_EXPORT
-#    ifdef vtkPVClientServerCoreCore_EXPORTS
+#    ifdef ClientServerCoreCore_EXPORTS
         /* We are building this library */
 #      define VTKPVCLIENTSERVERCORECORE_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,18 +23,20 @@
 
 #ifndef VTKPVCLIENTSERVERCORECORE_DEPRECATED
 #  define VTKPVCLIENTSERVERCORECORE_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVCLIENTSERVERCORECORE_DEPRECATED_EXPORT VTKPVCLIENTSERVERCORECORE_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVCLIENTSERVERCORECORE_DEPRECATED_NO_EXPORT VTKPVCLIENTSERVERCORECORE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVCLIENTSERVERCORECORE_NO_DEPRECATED
+#ifndef VTKPVCLIENTSERVERCORECORE_DEPRECATED_EXPORT
+#  define VTKPVCLIENTSERVERCORECORE_DEPRECATED_EXPORT VTKPVCLIENTSERVERCORECORE_EXPORT VTKPVCLIENTSERVERCORECORE_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersExtractionModule.h"
-#include "vtkFiltersParallelModule.h"
-#include "vtkPVVTKExtensionsCoreModule.h"
-
+#ifndef VTKPVCLIENTSERVERCORECORE_DEPRECATED_NO_EXPORT
+#  define VTKPVCLIENTSERVERCORECORE_DEPRECATED_NO_EXPORT VTKPVCLIENTSERVERCORECORE_NO_EXPORT VTKPVCLIENTSERVERCORECORE_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVCLIENTSERVERCORECORE_NO_DEPRECATED
+#    define VTKPVCLIENTSERVERCORECORE_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVCLIENTSERVERCORECORE_EXPORT_H */
