@@ -7,7 +7,7 @@
 #  define VTKPVSERVERMANAGERDEFAULT_NO_EXPORT
 #else
 #  ifndef VTKPVSERVERMANAGERDEFAULT_EXPORT
-#    ifdef vtkPVServerManagerDefault_EXPORTS
+#    ifdef ServerManagerDefault_EXPORTS
         /* We are building this library */
 #      define VTKPVSERVERMANAGERDEFAULT_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,20 @@
 
 #ifndef VTKPVSERVERMANAGERDEFAULT_DEPRECATED
 #  define VTKPVSERVERMANAGERDEFAULT_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVSERVERMANAGERDEFAULT_DEPRECATED_EXPORT VTKPVSERVERMANAGERDEFAULT_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVSERVERMANAGERDEFAULT_DEPRECATED_NO_EXPORT VTKPVSERVERMANAGERDEFAULT_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVSERVERMANAGERDEFAULT_NO_DEPRECATED
+#ifndef VTKPVSERVERMANAGERDEFAULT_DEPRECATED_EXPORT
+#  define VTKPVSERVERMANAGERDEFAULT_DEPRECATED_EXPORT VTKPVSERVERMANAGERDEFAULT_EXPORT VTKPVSERVERMANAGERDEFAULT_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkPVServerManagerRenderingModule.h"
-
+#ifndef VTKPVSERVERMANAGERDEFAULT_DEPRECATED_NO_EXPORT
+#  define VTKPVSERVERMANAGERDEFAULT_DEPRECATED_NO_EXPORT VTKPVSERVERMANAGERDEFAULT_NO_EXPORT VTKPVSERVERMANAGERDEFAULT_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVSERVERMANAGERDEFAULT_NO_DEPRECATED
+#    define VTKPVSERVERMANAGERDEFAULT_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVSERVERMANAGERDEFAULT_EXPORT_H */
