@@ -7,7 +7,7 @@
 #  define VTKPVVTKEXTENSIONSSIL_NO_EXPORT
 #else
 #  ifndef VTKPVVTKEXTENSIONSSIL_EXPORT
-#    ifdef vtkPVVTKExtensionsSIL_EXPORTS
+#    ifdef VTKExtensionsSIL_EXPORTS
         /* We are building this library */
 #      define VTKPVVTKEXTENSIONSSIL_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,20 @@
 
 #ifndef VTKPVVTKEXTENSIONSSIL_DEPRECATED
 #  define VTKPVVTKEXTENSIONSSIL_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVVTKEXTENSIONSSIL_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSSIL_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVVTKEXTENSIONSSIL_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSSIL_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVVTKEXTENSIONSSIL_NO_DEPRECATED
+#ifndef VTKPVVTKEXTENSIONSSIL_DEPRECATED_EXPORT
+#  define VTKPVVTKEXTENSIONSSIL_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSSIL_EXPORT VTKPVVTKEXTENSIONSSIL_DEPRECATED
 #endif
 
-
-
+#ifndef VTKPVVTKEXTENSIONSSIL_DEPRECATED_NO_EXPORT
+#  define VTKPVVTKEXTENSIONSSIL_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSSIL_NO_EXPORT VTKPVVTKEXTENSIONSSIL_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVVTKEXTENSIONSSIL_NO_DEPRECATED
+#    define VTKPVVTKEXTENSIONSSIL_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVVTKEXTENSIONSSIL_EXPORT_H */
